==> gnome-objc-0.99.8.tar.gz: gnome-objc-0.99.8/obgtk/obgtk.h <==
/* Released under the LGPL, please see the 'COPYING' file included. */
#ifndef OBGTK_H
#define OBGTK_H 1

#include <objc/objc.h>
#include <objc/objc-api.h>
#include <objc/Object.h>
#include <gtk/gtk.h>

#include <obgtk/obgtkAccelGroup.h>
#include <obgtk/obgtkAccelLabel.h>
#include <obgtk/obgtkAdjustment.h>
#include <obgtk/obgtkAlignment.h>
#include <obgtk/obgtkApp.h>
#include <obgtk/obgtkArrow.h>
#include <obgtk/obgtkAspectFrame.h>
#include <obgtk/obgtkBin.h>
#include <obgtk/obgtkBox.h>
#include <obgtk/obgtkButton.h>
#include <obgtk/obgtkButtonBox.h>
#include <obgtk/obgtkCheckButton.h>
#include <obgtk/obgtkCheckMenuItem.h>
#include <obgtk/obgtkCList.h>
#include <obgtk/obgtkCTree.h>
#include <obgtk/obgtkColorSelection.h>
#include <obgtk/obgtkColorSelectionDialog.h>
#include <obgtk/obgtkCombo.h>
#include <obgtk/obgtkContainer.h>
#include <obgtk/obgtkCurve.h>
#include <obgtk/obgtkData.h>
#include <obgtk/obgtkDialog.h>
#include <obgtk/obgtkDrawingArea.h>
#include <obgtk/obgtkEditable.h>
#include <obgtk/obgtkEntry.h>
#include <obgtk/obgtkEventBox.h>
#include <obgtk/obgtkFileSelection.h>
#include <obgtk/obgtkFixed.h>
#include <obgtk/obgtkFontSelection.h>
#include <obgtk/obgtkFrame.h>
#include <obgtk/obgtkGammaCurve.h>
#include <obgtk/obgtkHandleBox.h>
#include <obgtk/obgtkHBox.h>
#include <obgtk/obgtkHButtonBox.h>
#include <obgtk/obgtkHPaned.h>
#include <obgtk/obgtkHRuler.h>
#include <obgtk/obgtkHScale.h>
#include <obgtk/obgtkHScrollbar.h>
#include <obgtk/obgtkHSeparator.h>
#include <obgtk/obgtkImage.h>
#include <obgtk/obgtkInputDialog.h>
#include <obgtk/obgtkItem.h>
#include <obgtk/obgtkLabel.h>
#include <obgtk/obgtkLayout.h>
#include <obgtk/obgtkList.h>
#include <obgtk/obgtkListItem.h>
#include <obgtk/obgtkMenu.h>
#include <obgtk/obgtkMenuBar.h>
#include <obgtk/obgtkMenuItem.h>
#include <obgtk/obgtkMenuShell.h>
#include <obgtk/obgtkMisc.h>
#include <obgtk/obgtkNotebook.h>
#include <obgtk/obgtkObject.h>
#include <obgtk/obgtkOptionMenu.h>
#include <obgtk/obgtkPacker.h>
#include <obgtk/obgtkPaned.h>
#include <obgtk/obgtkPixmap.h>
#include <obgtk/obgtkPlug.h>
#include <obgtk/obgtkPreview.h>
#include <obgtk/obgtkProgress.h>
#include <obgtk/obgtkProgressBar.h>
#include <obgtk/obgtkRadioButton.h>
#include <obgtk/obgtkRadioMenuItem.h>
#include <obgtk/obgtkRange.h>
#include <obgtk/obgtkRuler.h>
#include <obgtk/obgtkScale.h>
#include <obgtk/obgtkScrollbar.h>
#include <obgtk/obgtkScrolledWindow.h>
#include <obgtk/obgtkSeparator.h>
#include <obgtk/obgtkSocket.h>
#include <obgtk/obgtkSpinButton.h>
#include <obgtk/obgtkTable.h>
#include <obgtk/obgtkTearoffMenuItem.h>
#include <obgtk/obgtkText.h>
#include <obgtk/obgtkTipsQuery.h>
#include <obgtk/obgtkToggleButton.h>
#include <obgtk/obgtkToolbar.h>
#include <obgtk/obgtkTooltips.h>
#include <obgtk/obgtkTree.h>
#include <obgtk/obgtkTreeItem.h>
#include <obgtk/obgtkViewport.h>
#include <obgtk/obgtkVButtonBox.h>
#include <obgtk/obgtkVBox.h>
#include <obgtk/obgtkVPaned.h>
#include <obgtk/obgtkVRuler.h>
#include <obgtk/obgtkVScale.h>
#include <obgtk/obgtkVScrollbar.h>
#include <obgtk/obgtkVSeparator.h>
#include <obgtk/obgtkWidget.h>
#include <obgtk/obgtkWindow.h>

#include <obgtk/obgtkStatusbar.h>

#endif /* OBGTK_H */

==> gnome-objc-1.0.40.tar.gz: gnome-objc-1.0.40/obgtk/obgtk.h <==
/* Released under the LGPL, please see the 'COPYING' file included. */
#ifndef OBGTK_H
#define OBGTK_H 1

#include <objc/objc.h>
#include <objc/objc-api.h>
#include <objc/Object.h>
#include <gtk/gtk.h>

#include <obgtk/obgtkAccelGroup.h>
#include <obgtk/obgtkAccelLabel.h>
#include <obgtk/obgtkAdjustment.h>
#include <obgtk/obgtkAlignment.h>
#include <obgtk/obgtkApp.h>
#include <obgtk/obgtkArrow.h>
#include <obgtk/obgtkAspectFrame.h>
#include <obgtk/obgtkBin.h>
#include <obgtk/obgtkBox.h>
#include <obgtk/obgtkButton.h>
#include <obgtk/obgtkButtonBox.h>
#include <obgtk/obgtkCList.h>
#include <obgtk/obgtkCTree.h>
#include <obgtk/obgtkCalendar.h>
#include <obgtk/obgtkCheckButton.h>
#include <obgtk/obgtkCheckMenuItem.h>
#include <obgtk/obgtkColorSelection.h>
#include <obgtk/obgtkColorSelectionDialog.h>
#include <obgtk/obgtkCombo.h>
#include <obgtk/obgtkContainer.h>
#include <obgtk/obgtkCurve.h>
#include <obgtk/obgtkData.h>
#include <obgtk/obgtkDialog.h>
#include <obgtk/obgtkDrawingArea.h>
#include <obgtk/obgtkEditable.h>
#include <obgtk/obgtkEntry.h>
#include <obgtk/obgtkEventBox.h>
#include <obgtk/obgtkFileSelection.h>
#include <obgtk/obgtkFixed.h>
#include <obgtk/obgtkFontSelection.h>
#include <obgtk/obgtkFontSelectionDialog.h>
#include <obgtk/obgtkFrame.h>
#include <obgtk/obgtkGammaCurve.h>
#include <obgtk/obgtkHBox.h>
#include <obgtk/obgtkHButtonBox.h>
#include <obgtk/obgtkHPaned.h>
#include <obgtk/obgtkHRuler.h>
#include <obgtk/obgtkHScale.h>
#include <obgtk/obgtkHScrollbar.h>
#include <obgtk/obgtkHSeparator.h>
#include <obgtk/obgtkHandleBox.h>
#include <obgtk/obgtkImage.h>
#include <obgtk/obgtkInputDialog.h>
#include <obgtk/obgtkInvisible.h>
#include <obgtk/obgtkItem.h>
#include <obgtk/obgtkLabel.h>
#include <obgtk/obgtkLayout.h>
#include <obgtk/obgtkList.h>
#include <obgtk/obgtkListItem.h>
#include <obgtk/obgtkMenu.h>
#include <obgtk/obgtkMenuBar.h>
#include <obgtk/obgtkMenuItem.h>
#include <obgtk/obgtkMenuShell.h>
#include <obgtk/obgtkMisc.h>
#include <obgtk/obgtkNotebook.h>
#include <obgtk/obgtkObject.h>
#include <obgtk/obgtkOptionMenu.h>
#include <obgtk/obgtkPacker.h>
#include <obgtk/obgtkPaned.h>
#include <obgtk/obgtkPixmap.h>
#include <obgtk/obgtkPlug.h>
#include <obgtk/obgtkPreview.h>
#include <obgtk/obgtkProgress.h>
#include <obgtk/obgtkProgressBar.h>
#include <obgtk/obgtkRadioButton.h>
#include <obgtk/obgtkRadioMenuItem.h>
#include <obgtk/obgtkRange.h>
#include <obgtk/obgtkRuler.h>
#include <obgtk/obgtkScale.h>
#include <obgtk/obgtkScrollbar.h>
#include <obgtk/obgtkScrolledWindow.h>
#include <obgtk/obgtkSeparator.h>
#include <obgtk/obgtkSocket.h>
#include <obgtk/obgtkSpinButton.h>
#include <obgtk/obgtkStatusbar.h>
#include <obgtk/obgtkTable.h>
#include <obgtk/obgtkTearoffMenuItem.h>
#include <obgtk/obgtkText.h>
#include <obgtk/obgtkTipsQuery.h>
#include <obgtk/obgtkToggleButton.h>
#include <obgtk/obgtkToolbar.h>
#include <obgtk/obgtkTooltips.h>
#include <obgtk/obgtkTree.h>
#include <obgtk/obgtkTreeItem.h>
#include <obgtk/obgtkVBox.h>
#include <obgtk/obgtkVButtonBox.h>
#include <obgtk/obgtkVPaned.h>
#include <obgtk/obgtkVRuler.h>
#include <obgtk/obgtkVScale.h>
#include <obgtk/obgtkVScrollbar.h>
#include <obgtk/obgtkVSeparator.h>
#include <obgtk/obgtkViewport.h>
#include <obgtk/obgtkWidget.h>
#include <obgtk/obgtkWindow.h>

#endif /* OBGTK_H */
